ScriptSnippetConfig

Struct ScriptSnippetConfig 

#[non_exhaustive]
pub struct ScriptSnippetConfig { pub show_outer_frame: bool, pub show_line_numbers: bool, pub show_module_path: bool, pub highlight_code: bool, pub unicode_drawing: bool, }
A configuration of options for drawing the ScriptSnippet object.

The Default implementation of this object provides canonical configuration options.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
show_outer_frame: bool

Whether the boxed frame should surround the code content from all sides.

The default value is true.

show_line_numbers: bool

Whether line numbers should be shown on the left of the code content.

The default value is true.

show_module_path: bool

Whether the full canonical script module path should be shown in the caption of the printed snippet.

If set to true, the snippet caption will look like: ‹package name›.‹module name› [<custom caption>].

Otherwise, the printer will only use the custom caption if specified.

The default value is true.

highlight_code: bool

If set to true, syntax highlighting will be applied to the source code. Otherwise, the source code will be monochrome.

The default value is true.

unicode_drawing: bool

Whether the snippet printer should use Unicode box drawing characters for decorative elements. Otherwise, the printer uses only ASCII box-drawing characters.

The default value is true.

Implementations

Source

impl ScriptSnippetConfig

pub const fn new() -> Self

The default constructor for the configuration.

pub const fn minimal() -> Self

The constructor for the configuration object that returns a configuration with all advanced drawing options disabled.