Ident

Enum Ident 

pub enum Ident {
    Rust(&'static RustIdent),
    Script(ScriptIdent),
}
An identifier within the Rust or Script code: let identifier = 10;.

You can retrieve the actual string of the identifier using the Display, Debug, and AsRef implementations of this type.

Unlike Origin and ScriptOrigin, the identifier’s string does not become obsolete or change even if the underlying Script source code has been modified. This object holds a copy of the string as it was at the time of the identifier’s creation.

Variants



Rust(&'static RustIdent)

An identifier declared in the Rust source code.



Script(ScriptIdent)

An identifier declared in the Script source code.

Implementations

Source

impl Ident

pub fn origin(&self) -> Origin

Returns the range in the Rust or Script source code that spans the underlying identifier.