pub enum NumberCastCause {
Infinite,
NAN,
Overflow,
Underflow,
}Expand description
A type of the RuntimeError::NumberCast error.
This object describes the reason why the source numeric value cannot be converted into the destination numeric value.
Variants
Infinite
The target type does not support representation of infinite numbers.
NAN
The target type does not support representation of NaN numbers.
Overflow
The source numeric value is too large for the range of the target type.
Underflow
The source numeric value is too small for the range of the target type.