ScriptDebug

Trait ScriptDebug 

pub trait ScriptDebug: Debug { }
A script debugging formatting operator.

Implementing this trait enables the Object::debug operation.

The underlying type on which this trait is implemented must also implement the Debug trait, which provides the actual implementation of the script debugging operation.

The trait must be implemented for the registered type, and the implementation must be exported using the export macro. For more details, see the module documentation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ScriptDebug for Range<usize>

Source

impl ScriptDebug for bool

Source

impl ScriptDebug for f32

Source

impl ScriptDebug for f64

Source

impl ScriptDebug for i8

Source

impl ScriptDebug for i16

Source

impl ScriptDebug for i32

Source

impl ScriptDebug for i64

Source

impl ScriptDebug for i128

Source

impl ScriptDebug for isize

Source

impl ScriptDebug for u8

Source

impl ScriptDebug for u16

Source

impl ScriptDebug for u32

Source

impl ScriptDebug for u64

Source

impl ScriptDebug for u128

Source

impl ScriptDebug for usize

Implementors