ScriptOr

Trait ScriptOr 

pub trait ScriptOr {
    type RHS: ?Sized;
    type Result: ?Sized;

    // Required method
    fn script_or(origin: Origin, lhs: Arg, rhs: Arg) -> RuntimeResult<Cell>;
}
A script logical disjunction operator: lhs || rhs.

Implementing this trait enables the Object::or operation.

The trait must be implemented for the registered type, and the implementation must be exported using the export macro. For more details, see the module documentation.

Required Associated Types

type RHS: ?Sized

A rough estimation of the type of the right-hand side of the operation.

This type must implement ScriptType.

type Result: ?Sized

A rough estimation of the result type of this operation.

This type must implement ScriptType.

Required Methods

fn script_or(origin: Origin, lhs: Arg, rhs: Arg) -> RuntimeResult<Cell>

Operation implementation.

The parameters and return type of this function correspond to those of the Object::or function.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ScriptOr for bool

Implementors