Arg

Struct Arg 

pub struct Arg {
    pub origin: Origin,
    pub data: Cell,
}
A wrapper for a Cell that is intended to be an argument of a function or an operator.

Fields

origin: Origin

The range in the Rust or Script source code that spans the location of the argument’s application.

data: Cell

The actual argument data.

Implementations

Source

impl Arg

pub fn new(origin: Origin, data: Cell) -> Self

A convenient constructor for creating an Arg.

pub fn provider(&mut self) -> Provider<'_>

Returns a borrowed Provider of the argument’s data Cell.

This function is useful for downcasting the argument into a Rust reference:

<&usize>::downcast(origin, arg.provider()).

Note that downcasting may render the argument’s data obsolete. Therefore, you shouldn’t use this Cell again. If needed, clone the Arg or the data Cell of this Arg object.

pub fn into_provider<'a>(self) -> Provider<'a>

Returns an owned Provider of the argument’s data Cell.

This function is useful for downcasting the argument into a Rust-owned data:

<usize>::downcast(origin, arg.into_provider()).

pub fn split(self) -> (Origin, Cell)

A helper function that splits an Arg into a tuple of origin and data.

pub fn take(arguments: &mut [Self], index: usize) -> Self

A helper function that retrieves an argument by index from an array of arguments.

This function returns an Arg object at arguments[index], replacing the original Cell with Cell::nil.

Panics

This function panics if the index is greater than or equal to the length of arguments.

pub unsafe fn take_unchecked(arguments: &mut [Self], index: usize) -> Self

An unsafe version of the Arg::take function.

Unlike the safe take function, the take_unchecked function does not check the arguments boundaries in production builds. As a result, it does not panic if the index exceeds the length of the input array.

Safety

The index must be less than arguments.len().