RustIdent

Struct RustIdent 

pub struct RustIdent {
    pub origin: &'static RustOrigin,
    pub string: &'static str,
}
An identifier within the Rust code: let identifier = 10;.

This object is typically created in static memory (static IDENT: RustIdent = RustIdent { ... }) using the export macro. Generally, you don’t need to create it manually.

Fields

origin: &'static RustOrigin

The range in the Rust source code that points to the underlying identifier.

string: &'static str

The string representation of the identifier.