pub struct ScriptIdent { /* private fields */ }Expand description
An identifier within the Script code: let identifier = 10;.
You cannot instantiate this object manually, but certain API functions return instances of it (e.g., VarSymbol::var_name).
You can retrieve the actual string of the identifier using the Display,
Debug, and AsRef
The ScriptIdent holds a copy of the identifier’s string from the time
of its creation. Therefore, the string does not become obsolete or change
even if the source code of the Script is modified.