pub trait ScriptNone { }Expand description
A marker trait indicating that the underlying type represents void data.
When this trait is implemented for a script type, the
Prototype::implements_none
function will return true.
The trait must be implemented for the registered type, and the implementation must be exported using the export macro. For more details, see the module documentation.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".